@@ -2,18 +2,18 @@
 
 set -eu
 
-base=$(readlink -f $(dirname $(readlink -f $0))/../..)
-. $base/lib/environment.sh
-prepare_args
+base=$(readlink -f "$(dirname "$(readlink -f "$0")")/../..")
+. "$base/lib/environment.sh"
 
+prepare_args
 rootfs="$1"
 
 # determine whether it's Debian or Ubuntu
-script=/usr/share/debootstrap/scripts/$debci_suite
-if [ -r $script ]; then
-  if grep -q ubuntu.com $script; then
+script="/usr/share/debootstrap/scripts/${debci_suite:?}"
+if [ -r "$script" ]; then
+  if grep -q ubuntu.com "$script"; then
     distro=ubuntu
-  elif grep -q kali.org $script; then
+  elif grep -q kali.org "$script"; then
     distro=kali
   else
     distro=debian
@@ -26,7 +26,6 @@ fi
 if [ "$distro" = debian ]; then
   debci-generate-apt-sources \
     --source \
-    --buildd \
     -- \
     "$debci_suite" \
     > "$rootfs/etc/apt/sources.list"
@@ -36,18 +35,24 @@ if [ "$distro" = debian ]; then
   done
 fi
 
+# convert apt proxy pointing to the VM's host back to localhost
+proxy_opt=
+RES=$(chroot "${rootfs}" apt-config shell PROXY Acquire::http::Proxy)
+eval "$RES"
+if [ -n "$PROXY" ]; then
+  proxy_opt="-o Acquire::http::Proxy=$(echo "${PROXY}" | sed -e 's/10.0.2.2/127.0.0.1/')"
+fi
+# shellcheck disable=SC2086
 DEBIAN_FRONTEND=noninteractive \
   chroot "$rootfs"  \
-  apt-get install dpkg-dev -q -y --no-install-recommends
+  apt-get install $proxy_opt dpkg-dev ca-certificates auto-apt-proxy -q -y --no-install-recommends
 
 DEBIAN_FRONTEND=noninteractive \
   chroot "$rootfs"  \
   apt-get clean
 
 chroot "$rootfs"  \
-  adduser \
-    --system \
-    --disabled-password \
-    --shell /bin/sh \
+  useradd \
     --home /home/debci \
+    --create-home \
     debci
