@@ -26,6 +26,7 @@ module Debci
     :autopkgtest_basedir,
     :auth_fail_page,
     :backend,
+    :backend_list,
     :config_dir,
     :data_basedir,
     :data_retention_days,
@@ -35,8 +36,11 @@ module Debci
     :html_dir,
     :packages_dir,
     :pending_status_per_page,
+    :slow_tests_duration_minutes,
     :status_visible_days,
     :quiet,
+    :salsa_client_id,
+    :salsa_client_secret,
     :secrets_dir,
     :sendmail_from,
     :sendmail_to,
@@ -50,7 +54,7 @@ module Debci
     # for development usage
     if !ENV['AUTOPKGTEST_TMP']
       bin = "#{File.dirname(__FILE__)}/../../bin"
-      if File.exists?(bin)
+      if File.exist?(bin)
         ENV['PATH'] = [bin,ENV['PATH']].join(':')
       end
     end
@@ -63,6 +67,7 @@ module Debci
         'data_retention_days' => lambda { |x| x.to_i },
         'status_visible_days' => lambda { |x| x.to_i },
         'failing_packages_per_page' => lambda { |x| x.to_i },
+        'slow_tests_duration_minutes' => lambda { |x| x.to_i }
       }
     end
 
