@@ -20,6 +20,17 @@ module Debci
       end
     end
 
+    # Package search
+    get '/-/search' do
+      @query = params[:query]
+      records = Debci::Package.where("name LIKE :query", query: "%#{@query}%").order(:name)
+
+      # pagination
+      results = get_page_params(records, params[:page], 10)
+
+      erb :package_search_results, locals: { results: results }
+    end
+
     # Package listing pages
     get "/:prefix/" do
       @package_prefixes = Debci::Package.prefixes
@@ -36,6 +47,7 @@ module Debci
       halt 404 unless params[:package].start_with?(params[:prefix])
       begin
         @package = Debci::Package.find_by_name!(params[:package])
+        @pending_jobs = @package.jobs.pending
       rescue ActiveRecord::RecordNotFound
         halt 404
       end
@@ -50,6 +62,8 @@ module Debci
     get "/:prefix/:package/:suite/:architecture/" do
       halt 404 unless params[:package].start_with?(params[:prefix])
       package = Debci::Package.find_by_name(params[:package])
+      halt 404 unless package
+
       @package = package
       @suite = params[:suite]
       @architecture = params[:architecture]
@@ -58,8 +72,12 @@ module Debci
       @site_url = expand_url(Debci.config.url_base, @suite)
       @artifacts_url_base = expand_url(Debci.config.artifacts_url_base, @suite)
       @moretitle = "#{package.name}/#{@suite}/#{@architecture}"
-      @history = package.history(@suite, @architecture).reverse
-      erb :history
+      @history = package.history(@suite, @architecture).reverse_order
+
+      # pagination
+      results = get_page_params(@history, params[:page], 500)
+
+      erb :history, locals: { results: results }
     end
     get "/:prefix/:package/:suite/:architecture" do
       redirect "#{request.path}/"
