@@ -38,6 +38,7 @@ module Debci
         html.status_slow('status/slow/index.html')
         html.status_pending_jobs('status/pending')
         html.status_failing('status/failing')
+        html.reject_list
         html.blacklist
         html.platform_specific_issues('status/platform-specific-issues')
       end
@@ -146,22 +147,22 @@ module Debci
     end
 
     class PackageJSON < Rooted
-      def history(hist)
-        package = hist.package
-        suite = hist.suite
-        arch = hist.arch
+      def history(job_history)
+        package = job_history.package
+        suite = job_history.suite
+        arch = job_history.arch
         write_json(
-          hist,
+          job_history,
           [suite, arch, package.prefix, package.name, 'history.json']
         )
       end
 
-      def latest(hist)
-        package = hist.package
-        suite = hist.suite
-        arch = hist.arch
+      def latest(job_history)
+        package = job_history.package
+        suite = job_history.suite
+        arch = job_history.arch
         write_json(
-          hist.last,
+          job_history.last,
           [suite, arch, package.prefix, package.name, 'latest.json']
         )
       end
@@ -181,11 +182,11 @@ module Debci
     end
 
     class Autopkgtest < Rooted
-      def link_latest(hist)
-        package = hist.package
-        suite = hist.suite
-        arch = hist.arch
-        job = hist.last
+      def link_latest(job_history)
+        package = job_history.package
+        suite = job_history.suite
+        arch = job_history.arch
+        job = job_history.last
         return unless job
 
         link = root / suite / arch / package.prefix / package.name / 'latest-autopkgtest'
@@ -246,7 +247,7 @@ module Debci
     end
 
     def status_alerts(filename)
-      # Packages with atleast one visible tmpfail status
+      # Packages with at least one visible tmpfail status
       @tmpfail = Debci::Job.tmpfail.visible
       @alert_number = @tmpfail.length
       expand_template(:status_alerts, filename)
@@ -299,10 +300,22 @@ module Debci
       end
     end
 
-    def blacklist
+    def reject_list
       @status_nav = load_template(:status_nav)
-      @blacklist = Debci.blacklist
-      expand_template(:blacklist, 'status/blacklist/index.html')
+      @reject_list = Debci.reject_list
+      expand_template(:reject_list, 'status/reject_list/index.html')
+    end
+
+    def blacklist
+      abs_filename = File.join(root_directory, 'status/blacklist/index.html')
+      FileUtils.mkdir_p(File.dirname(abs_filename))
+
+      File.open(abs_filename, 'w') do |f|
+        blacklist_html = File.join(File.dirname(__FILE__), 'html/templates/blacklist.erb')
+        File.open(blacklist_html, 'r') do |html|
+          f.write(html.read)
+        end
+      end
     end
 
     # expand { SUITE } macro in URLs
