@@ -1,4 +1,5 @@
 require 'debci'
+require 'debci/user'
 require 'debci/amqp'
 require 'debci/db'
 require 'debci/package'
@@ -9,11 +10,18 @@ require 'debci/test/paths'
 require 'cgi'
 require 'time'
 require 'pathname'
+require 'debci/validators'
+require 'debci/worker'
 
 module Debci
   class Job < ActiveRecord::Base
 
+    include Debci::Validators::APTSource
+
     belongs_to :package, class_name: 'Debci::Package'
+    belongs_to :requestor, class_name: 'Debci::User', foreign_key: 'requestor_id'
+    belongs_to :worker, class_name: 'Debci::Worker', foreign_key: 'worker_id'
+    validates :requestor, presence: true
     has_many :package_status, class_name: 'Debci::PackageStatus'
 
     scope :newsworthy, -> { not_pinned.where(['status in (?) AND previous_status in (?) and status != previous_status', ['pass', 'fail', 'neutral'], ['pass', 'fail', 'neutral']]) }
@@ -22,13 +30,15 @@ module Debci
 
     scope :not_pinned, -> { where('pin_packages is NULL') }
 
+    scope :not_private, -> { where(is_private: false) }
+
     def pinned?
       !pin_packages.empty?
     end
 
     # FIXME: move to Debci::PackageStatus
     scope :status_on, lambda { |suite, arch|
-      joins(:package_status).where(['package_statuses.suite IN (?) AND package_statuses.arch IN (?)', suite, arch])
+      not_private.joins(:package_status, :package).where(packages: { removed: false }).where(['package_statuses.suite IN (?) AND package_statuses.arch IN (?)', suite, arch])
     }
 
     # FIXME: move to Debci::PackageStatus
@@ -53,10 +63,11 @@ module Debci
 
     # FIXME: move to Debci::PackageStatus
     scope :slow, lambda {
-      all_status.where('duration_seconds > :time', time: 1.hour)
+      all_status.where('duration_seconds > :time', time: Debci.config.slow_tests_duration_minutes.minutes)
     }
 
     after_save do |job|
+      next if job.is_private
       next unless job.status
       next unless job.date
       next if job.pinned?
@@ -84,6 +95,7 @@ module Debci
     include Debci::Test::Paths
 
     serialize :pin_packages, Array
+    serialize :extra_apt_sources, Array
 
     class InvalidStatusFile < RuntimeError; end
 
@@ -119,7 +131,7 @@ module Debci
 
         worker_file = (src / 'worker')
         if worker_file.exist?
-          job.worker = worker_file.read.strip
+          job.worker = Debci::Worker.find_or_create_by!(name: worker_file.read.strip)
         end
 
         testpkg_version = src / 'testpkg-version'
@@ -181,11 +193,11 @@ module Debci
     end
 
     def self.pending
-      jobs = Debci::Job.where(status: nil).order(:created_at)
+      Debci::Job.includes(:requestor).not_private.where(status: nil).order(:created_at)
     end
 
     def self.history(package, suite, arch)
-      Debci::Job.finished.where(
+      Debci::Job.includes(:requestor).not_private.finished.where(
         package: package,
         suite: suite,
         arch: arch
@@ -237,11 +249,18 @@ module Debci
           parameters << "pin-packages:#{suite}=#{pkg}"
         end
       end
+      Array(self.extra_apt_sources).each do |src|
+        parameters << "extra-apt-source:#{Base64.strict_encode64(src)}"
+      end
       parameters
     end
 
-    def enqueue(priority = 0)
-      queue = Debci::AMQP.get_queue(arch)
+    def enqueue(priority = 5)
+      queue = if package.backend.nil?
+                Debci::AMQP.get_queue(arch)
+              else
+                Debci::AMQP.get_queue(arch, package.backend)
+              end
       parameters = enqueue_parameters
       queue.publish("%s %s %s" % [package.name, suite, parameters.join(' ')], priority: priority)
     end
