@@ -10,6 +10,7 @@ module Debci
     has_many :jobs, class_name: 'Debci::Job'
     has_many :package_status, class_name: 'Debci::PackageStatus'
     validates_format_of :name, with: /\A[a-z0-9][a-z0-9+.-]+\z/
+    validates :backend, inclusion: { in: ->(_) { Debci.config.backend_list } }, allow_nil: true
 
     scope :by_prefix, lambda { |p|
       if p == 'l'
@@ -28,7 +29,7 @@ module Debci
     #     ]
     #
     # Each cell of the matrix contains a Debci::Job object.
-    # Note: Contains statuses which are not blacklisted
+    # Note: Contains statuses which are not rejectlisted
     def status
       @status ||=
         begin
@@ -83,12 +84,12 @@ module Debci
       self.class.prefix(name)
     end
 
-    def blacklisted?(params = {})
-      Debci.blacklist.include?(name, params)
+    def reject_listed?(params = {})
+      Debci.reject_list.include?(name, params)
     end
 
-    def blacklist_comment(params = {})
-      Debci.blacklist.comment(name, params)
+    def reject_list_comment(params = {})
+      Debci.reject_list.comment(name, params)
     end
 
     def last_updated_at(suite = nil)
