@@ -3,6 +3,7 @@ require 'debci/api'
 require 'debci/test_handler'
 require 'rack/test'
 require 'spec_mock_server'
+require 'json'
 
 describe Debci::API do
   include Rack::Test::Methods
@@ -22,14 +23,24 @@ describe Debci::API do
   let(:suite) { Debci.config.suite }
   let(:arch) { Debci.config.arch }
 
-  let(:theuser) do
-    Debci::User.create!(username: 'theuser')
-  end
+  let(:theuser) { Debci::User.create!(username: 'theuser') }
 
   before do
     allow(Debci.config).to receive(:secrets_dir).and_return(tmpdir)
   end
 
+  before do
+    allow(Debci.extra_apt_sources_list).to receive(:find)
+      .with('bullseye-fasttrack')
+      .and_return(Debci::ExtraAptSource.new('deb https://fasttrack.debian.net/debian-fasttrack/ bullseye-fasttrack main contrib'))
+    allow(Debci.extra_apt_sources_list).to receive(:find)
+      .with('bullseye-backports-staging')
+      .and_return(Debci::ExtraAptSource.new('deb https://fasttrack.debian.net/debian-fasttrack/ bullseye-backports-staging main contrib', [123, 456]))
+    allow(Debci.extra_apt_sources_list).to receive(:find)
+      .with('something-random')
+      .and_return(nil)
+  end
+
   context 'authentication' do
     it 'does not authenticate with an invalid key' do
       header 'Auth-Key', '1234567890'
@@ -47,32 +58,6 @@ describe Debci::API do
     end
   end
 
-  context 'getting a key' do
-    it "can't get a key with invalid auth" do
-      keys = Debci::Key.count
-
-      post '/api/v1/getkey'
-      expect(last_response.status).to eq(403)
-
-      expect(Debci::Key.count).to eq(keys)
-    end
-
-    it 'gets a key based on client certificate' do
-      post '/api/v1/getkey', {}, 'SSL_CLIENT_S_DN_CN' => 'foo@bar.com'
-      expect(last_response.status).to eq(201)
-
-      user = Debci::User.find_by(username: 'foo@bar.com')
-      key = user.keys.first
-      expect(key).to_not be_nil
-    end
-
-    it 'displays a user-friendly page' do
-      get '/api/v1/getkey'
-      expect(last_response.status).to eq(200)
-      expect(last_response.content_type).to match('text/html')
-    end
-  end
-
   context 'receiving test requests' do
     before do
       key = Debci::Key.create!(user: theuser).key
@@ -90,7 +75,7 @@ describe Debci::API do
         expect(job.package.name).to eq('mypackage')
         expect(job.suite).to eq(suite)
         expect(job.arch).to eq(arch)
-        expect(job.requestor).to eq('theuser')
+        expect(job.requestor).to eq(theuser)
 
         expect(last_response.status).to eq(201)
       end
@@ -100,8 +85,8 @@ describe Debci::API do
         post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch, priority: 8 }
       end
 
-      it 'rejects blacklisted package' do
-        allow_any_instance_of(Debci::Blacklist).to receive(:include?)
+      it 'rejects rejectlisted package' do
+        allow_any_instance_of(Debci::RejectList).to receive(:include?)
           .with('mypackage', suite: suite, arch: arch).and_return(true)
         post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }
         expect(last_response.status).to eq(400)
@@ -131,6 +116,46 @@ describe Debci::API do
         post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: 'suite', arch: arch, priority: 11 }
         expect(last_response.status).to eq(400)
       end
+
+      it 'handles is_private flag' do
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }, is_private: "true"
+        expect(last_response.status).to eq(201)
+        expect(Debci::Job.last.is_private).to eq(true)
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }, is_private: "false"
+        expect(last_response.status).to eq(201)
+        expect(Debci::Job.last.is_private).to eq(false)
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }
+        expect(last_response.status).to eq(201)
+        expect(Debci::Job.last.is_private).to eq(false)
+      end
+
+      it 'accepts only valid bool value for is_private flag if present ' do
+        jobs = Debci::Job.count
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }, is_private: "abc"
+        expect(last_response.status).to eq(400)
+        expect(Debci::Job.count).to eq(jobs)
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }, is_private: "true"
+        expect(last_response.status).to eq(201)
+        expect(Debci::Job.last.is_private).to eq(true)
+      end
+
+      it 'handles extra-apt-sources' do
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }, extra_apt_sources: '[
+          "bullseye-fasttrack"]'
+        expect(last_response.status).to eq(201)
+        expect(Debci::Job.last.extra_apt_sources).to eq(["deb https://fasttrack.debian.net/debian-fasttrack/ bullseye-fasttrack main contrib"])
+      end
+
+      it 'reject invalid extra-apt-sources and the name of invalid apt-sources is present in response' do
+        post '/api/v1/test/%<suite>s/%<arch>s/mypackage' % { suite: suite, arch: arch }, extra_apt_sources: '[
+          "something-random",
+          "bullseye-fasttrack",
+          "bullseye-backports-staging"]'
+        expect(last_response.status).to eq(400)
+        expect(last_response.body).to match('something-random')
+        expect(last_response.body).to match('bullseye-backports-staging')
+        expect(last_response.body).to_not match('bullseye-fasttrack')
+      end
     end
 
     context 'for a test batch' do
@@ -144,7 +169,7 @@ describe Debci::API do
           job = Debci::Job.where(package: package).last
           expect(job.suite).to eq(suite)
           expect(job.arch).to eq(arch)
-          expect(job.requestor).to eq('theuser')
+          expect(job.requestor).to eq(theuser)
         end
 
         expect(last_response.status).to eq(201)
@@ -162,9 +187,9 @@ describe Debci::API do
         expect(last_response.status).to eq(400)
       end
 
-      it 'marks blacklisted packages as failed right away' do
-        allow_any_instance_of(Debci::Blacklist).to receive(:include?).with('package1', suite: suite, arch: arch).and_return(true)
-        allow_any_instance_of(Debci::Blacklist).to receive(:include?).with('package2', suite: suite, arch: arch).and_return(false)
+      it 'marks rejectlisted packages as failed right away' do
+        allow_any_instance_of(Debci::RejectList).to receive(:include?).with('package1', suite: suite, arch: arch).and_return(true)
+        allow_any_instance_of(Debci::RejectList).to receive(:include?).with('package2', suite: suite, arch: arch).and_return(false)
 
         expect_any_instance_of(Debci::Job).to receive(:enqueue).once
 
@@ -230,6 +255,46 @@ describe Debci::API do
           post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: Rack::Test::UploadedFile.new(batch_test_file, 'application/json')
         end.to raise_error(Exception)
       end
+
+      it 'handles is_private flag' do
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: '[{"package": "package1", "is_private": true}, {"package": "package2"}]'
+        expect(last_response.status).to eq(201)
+        package = Debci::Package.find_by!(name: 'package1')
+        job = Debci::Job.where(package: package).last
+        expect(job.is_private).to eq(true)
+        package = Debci::Package.find_by!(name: 'package2')
+        job = Debci::Job.where(package: package).last
+        expect(job.is_private).to eq(false)
+      end
+
+      it 'accepts only valid bool value for is_private flag if present ' do
+        jobs = Debci::Job.count
+        post '/api/v1/test/%<suite>s/%<arch>se' % { suite: suite, arch: arch }, tests: '[{"package": "package1", "is_private": "abc"}, {"package": "package2"}]'
+        expect(last_response.status).to eq(400)
+        expect(Debci::Job.count).to eq(jobs)
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: '[{"package": "package1", "is_private": true}]'
+        expect(last_response.status).to eq(201)
+        package = Debci::Package.find_by!(name: 'package1')
+        job = Debci::Job.where(package: package).last
+        expect(job.is_private).to eq(true)
+      end
+
+      it 'handles extra-apt-sources' do
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch }, tests: File.read(test_file)
+        expect(last_response.status).to eq(201)
+        package1 = Debci::Package.find_by(name: 'package1')
+        job = Debci::Job.find_by(suite: suite, arch: arch, package: package1)
+        expect(job.extra_apt_sources).to eq(["deb https://fasttrack.debian.net/debian-fasttrack/ bullseye-fasttrack main contrib"])
+      end
+
+      it 'reject invalid extra-apt-sources and the name of invalid apt-sources is present in response' do
+        post '/api/v1/test/%<suite>s/%<arch>s' % { suite: suite, arch: arch },
+             tests: '[{"package": "package1","extra-apt-sources": ["bullseye-backports-staging", "bullseye-fasttrack", "something-random"]}]'
+        expect(last_response.status).to eq(400)
+        expect(last_response.body).to match('bullseye-backports-staging')
+        expect(last_response.body).to match('something-random')
+        expect(last_response.body).to_not match('bullseye-fasttrack')
+      end
     end
   end
 
@@ -245,7 +310,7 @@ describe Debci::API do
         package: package,
         suite: suite,
         arch: arch,
-        requestor: theuser.username,
+        requestor: theuser,
       )
       get '/api/v1/test'
       data = JSON.parse(last_response.body)
@@ -259,14 +324,14 @@ describe Debci::API do
         package: package,
         suite: suite,
         arch: arch,
-        requestor: theuser.username,
+        requestor: theuser,
         updated_at: Time.now - 1.day
       )
       new_job = Debci::Job.create(
         package: package,
         suite: suite,
         arch: arch,
-        requestor: theuser.username,
+        requestor: theuser,
       )
       get '/api/v1/test', since: (Time.now - 1.hour).to_i.to_s
       ids = JSON.parse(last_response.body)["results"].map { |e| e["run_id"] }
@@ -279,14 +344,14 @@ describe Debci::API do
         package: package,
         suite: suite,
         arch: arch,
-        requestor: theuser.username,
+        requestor: theuser,
         updated_at: Time.now,
       )
       job1 = Debci::Job.create(
         package: package,
         suite: suite,
         arch: arch,
-        requestor: theuser.username,
+        requestor: theuser,
         updated_at: Time.now - 1.hour
       )
       get '/api/v1/test'
@@ -322,100 +387,58 @@ describe Debci::API do
     end
   end
 
-  context 'retriggers' do
-    it 'rejects non-authenticated requests' do
-      post '/api/v1/retry/1'
-      expect(last_response.status).to eq(403)
+  context 'displays a user-friendly page to retrigger test' do
+    it 'redirects to self service section' do
+      get 'api/v1/retry/1'
+      expect(last_response.status).to eq(302)
+      expect(last_response.location).to match(%r{/user/:user/retry/1$})
+    end
+  end
+
+  context 'publishing private tests' do
+    before do
+      key = Debci::Key.create!(user: theuser).key
+
+      header 'Auth-Key', key
     end
 
-    it 'displays a user friendly page to authenticated users' do
-      package = Debci::Package.create!(name: 'mypackage')
-      user = 'myuser'
-      trigger = 'mypackage/0.0.1'
-      pin_packages = ['src:mypackage', 'unstable']
-      job = Debci::Job.create(
-        package: package,
+    let(:data) do
+      {
         suite: suite,
         arch: arch,
-        requestor: user,
-        trigger: trigger,
-        pin_packages: pin_packages
-      )
-      get "/api/v1/retry/#{job.id}", {}, 'SSL_CLIENT_S_DN_CN' => 'foo@bar.com'
+        package: Debci::Package.create!(name: 'mypackage')
+      }
+    end
+
+    let(:private_job) { Debci::Job.create!(data.merge(requestor: theuser, is_private: true)) }
+
+    it 'ignores run_id of a job not of logged in user' do
+      another_user = Debci::User.create!(username: 'anotheruser')
+      job = Debci::Job.create!(data.merge(requestor: another_user, is_private: true))
+      post 'api/v1/test/publish', run_ids: [private_job.id, job.id].join(",")
       expect(last_response.status).to eq(200)
-      expect(last_response.content_type).to match('text/html')
+      expect(Debci::Job.find(private_job.id).is_private).to eq(false)
+      expect(Debci::Job.find(job.id).is_private).to eq(true)
     end
 
-    it 'displays a "Forbidden" page to non-authenticated users' do
-      get '/api/v1/retry/1'
-      expect(last_response.status).to eq(403)
-      expect(last_response.content_type).to match('text/html')
+    it 'ignores run_id of non-private job' do
+      job = Debci::Job.create!(data.merge(requestor: theuser, is_private: false))
+      post 'api/v1/test/publish', run_ids: [private_job.id, job.id].join(",")
+      expect(last_response.status).to eq(200)
+      expect(Debci::Job.find(private_job.id).is_private).to eq(false)
     end
 
-    it 'can retrigger a valid request with key' do
-      package = Debci::Package.create!(name: 'mypackage')
-      user = 'myuser'
-      trigger = 'mypackage/0.0.1'
-      pin_packages = ['src:mypackage', 'unstable']
-      Debci::Job.create(
-        package: package,
-        suite: suite,
-        arch: arch,
-        requestor: user,
-        trigger: trigger,
-        pin_packages: pin_packages
-      )
-
-      job_org = Debci::Job.last
-
-      # Here we are going to retrigger it
-      key = Debci::Key.create!(user: theuser).key
-      header 'Auth-Key', key
-      post "/api/v1/retry/#{job_org.run_id}"
-
-      job = Debci::Job.last
-      expect(job.run_id).to eq(job_org.run_id + 1)
-      expect(job.package).to eq(package)
-      expect(job.suite).to eq(suite)
-      expect(job.arch).to eq(arch)
-      expect(job.requestor).to eq(user)
-      expect(job.trigger).to eq(trigger)
-      expect(job.pin_packages).to eq(pin_packages)
-
-      expect(last_response.status).to eq(201)
-    end
-
-    it 'can retrigger a valid request with client certificate' do
-      package = Debci::Package.create!(name: 'mypackage')
-      user = 'myuser'
-      trigger = 'mypackage/0.0.1'
-      pin_packages = ['src:mypackage', 'unstable']
-      Debci::Job.create(
-        package: package,
-        suite: suite,
-        arch: arch,
-        requestor: user,
-        trigger: trigger,
-        pin_packages: pin_packages
-      )
-
-      job_org = Debci::Job.last
-
-      # Here we are going to retrigger it
-      post "/api/v1/retry/#{job_org.run_id}", {}, 'SSL_CLIENT_S_DN_CN' => 'foo@bar.com'
-
-      expect(last_response.status).to eq(201)
-
-      job = Debci::Job.last
-      expect(job.run_id).to eq(job_org.run_id + 1)
-    end
-
-    it 'rejects to retrigger an unknown run_id' do
-      key = Debci::Key.create!(user: theuser).key
-      header 'Auth-Key', key
-      post '/api/v1/retry/1'
-
-      expect(last_response.status).to eq(400)
+    [
+      'áéíóú',
+      'ab123, ab7.5',
+      ',   ,  ,',
+    ].each do |invalid|
+      it 'ignores the invalid args and cleans input' do
+        expect(Debci::Job.find(private_job.id).is_private).to eq(true)
+        post 'api/v1/test/publish', run_ids: [private_job.id, invalid].join(",")
+        expect(last_response.status).to eq(200)
+        expect(Debci::Job.find(private_job.id).is_private).to eq(false)
+      end
     end
   end
 end
