@@ -5,12 +5,13 @@ describe Debci::Collector do
   include_context 'tmpdir'
   let(:collector) { Debci::Collector.new }
   let(:package) { Debci::Package.create!(name: 'mypkg') }
+  let(:theuser) { Debci::User.create!(username: 'debci') }
   let(:job) do
     Debci::Job.create!(
       package: package,
       suite: 'unstable',
       arch: 'amd64',
-      requestor: 'debci',
+      requestor: theuser,
     )
   end
 
@@ -20,6 +21,10 @@ describe Debci::Collector do
     end
   end
 
+  before do
+    allow_any_instance_of(Debci::Config).to receive(:autopkgtest_basedir).and_return(File.join(tmpdir, "autopkgtest"))
+  end
+
   it 'receives payload, updates database and HTML' do
     expect(Debci::HTML).to receive(:update_package).with(package, 'unstable', 'amd64')
     collector.receive_payload(tmpdir, payload)
