@@ -9,6 +9,8 @@ require 'rack/test'
 describe Debci::Frontend do
   include Rack::Test::Methods
 
+  let(:theuser) { Debci::User.create!(username: 'debci') }
+
   class Frontend < Debci::Frontend
     set :raise_errors, true
     set :show_exceptions, false
@@ -64,6 +66,7 @@ describe Debci::Frontend do
         status: "pass",
         created_at: Time.now,
         updated_at: Time.now,
+        requestor: theuser
       )
 
       get "/packages/r/rake/#{suite}/#{arch}/"
@@ -74,6 +77,11 @@ describe Debci::Frontend do
       get "/packages/f/rake/#{suite}/#{arch}/"
       expect(last_response.status).to eq(404)
     end
+
+    it 'responds with 404 to non-existing package' do
+      get "/packages/x/x-missing/#{suite}/#{arch}/"
+      expect(last_response.status).to eq(404)
+    end
   end
 
   context 'redirecting' do
@@ -96,4 +104,32 @@ describe Debci::Frontend do
       expect(last_response.headers['Cache-Control']).to match(/max-age=31556952/)
     end
   end
+
+  context "searching" do
+    it 'finds packages by name' do
+      Debci::Package.create(name: "foobar")
+      get '/packages/-/search', query: "foo"
+      expect(last_response.body).to match(/foobar/)
+    end
+
+    it 'displays second page' do
+      ('a'..'z').each { |i| Debci::Package.create(name: "foobar-#{i}") }
+      get '/packages/-/search', query: "foo", page: "2"
+      expect(last_response.body).to match(/foobar-m/)
+    end
+  end
+
+  context "displaying pending jobs" do
+    before do
+      @rake.jobs.create!(trigger: 'current-package', requestor: theuser)
+    end
+    it 'list pending jobs for the current package only' do
+      get '/packages/r/rake/'
+      expect(last_response.body).to match('current-package')
+    end
+    it 'does not display jobs from other packages' do
+      get '/packages/r/ruby-defaults/'
+      expect(last_response.body).to_not match('current-package')
+    end
+  end
 end
