@@ -8,7 +8,8 @@ describe Debci::Job do
   include_context 'tmpdir'
 
   let(:package) { Debci::Package.create!(name: 'mypackage') }
-  let(:new_job) { Debci::Job.create!(package: package) }
+  let(:theuser) { Debci::User.create!(username: 'user') }
+  let(:new_job) { Debci::Job.create!(package: package, requestor: theuser) }
 
   it 'sets created_at' do
     expect(new_job.created_at).to_not be_nil
@@ -26,12 +27,19 @@ describe Debci::Job do
 
   it 'sorts pending jobs with older first' do
     yesterday = Time.now - 1.day
-    job1 = Debci::Job.create(package: package, created_at: Time.now)
-    job0 = Debci::Job.create(package: package, created_at: yesterday)
+    job1 = Debci::Job.create(package: package, created_at: Time.now, requestor: theuser)
+    job0 = Debci::Job.create(package: package, created_at: yesterday, requestor: theuser)
 
     expect(Debci::Job.pending).to eq([job0, job1])
   end
 
+  it 'excludes private jobs from pending jobs' do
+    job1 = Debci::Job.create(package: package, created_at: Time.now, is_private: true, requestor: theuser)
+    job2 = Debci::Job.create(package: package, created_at: Time.now, requestor: theuser)
+    expect(Debci::Job.pending).to_not include(job1)
+    expect(Debci::Job.pending).to include(job2)
+  end
+
   context 'when enqueing' do
     it 'escapes trigger' do
       job = Debci::Job.new(trigger: 'foo bar')
@@ -56,13 +64,24 @@ describe Debci::Job do
       expect(job.enqueue_parameters).to include('pin-packages:unstable=src:foo')
       expect(job.enqueue_parameters).to include('pin-packages:unstable=src:bar')
     end
+
+    it 'encodes each extra-apt-sources string to base64' do
+      job = Debci::Job.new(extra_apt_sources: ["deb http://deb.debian.org/debian experimental main"])
+      expect(job.enqueue_parameters).to include(%r'extra-apt-source:([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)?')
+    end
+
+    it 'handles multiple extra-apt-sources' do
+      job = Debci::Job.new(extra_apt_sources: ["deb http://deb.debian.org/debian experimental main", "deb http://security.debian.org/debian-security bullseye-security main"])
+      expect(job.enqueue_parameters).to include("extra-apt-source:#{Base64.strict_encode64('deb http://deb.debian.org/debian experimental main')}")
+      expect(job.enqueue_parameters).to include("extra-apt-source:#{Base64.strict_encode64('deb http://security.debian.org/debian-security bullseye-security main')}")
+    end
   end
 
   let(:suite) { 'unstable' }
   let(:arch) { 'amd64' }
 
   it 'imports status file' do
-    job = Debci::Job.create(package: package, suite: suite, arch: arch)
+    job = Debci::Job.create(package: package, suite: suite, arch: arch, requestor: theuser)
     file = Tempfile.new('foo')
     file.write(
       {
@@ -95,7 +114,7 @@ describe Debci::Job do
   end
 
   it 'refuses to import incorrect jobs' do
-    job = Debci::Job.create(package: package, suite: suite, arch: arch)
+    job = Debci::Job.create(package: package, suite: suite, arch: arch, requestor: theuser)
     file = Tempfile.new('foo')
     file.write(
       {
@@ -120,7 +139,7 @@ describe Debci::Job do
 
   it 'takes ridiculously large version numbers' do
     v = "#{'1.' * 100}0"
-    Debci::Job.create!(package: package, version: v)
+    Debci::Job.create!(package: package, version: v, requestor: theuser)
   end
 
   context "history" do
@@ -131,20 +150,23 @@ describe Debci::Job do
         suite: 'testing',
         arch: 'amd64',
         status: 'pass',
-        date: '2019-02-02 11:00'
+        date: '2019-02-02 11:00',
+        requestor: theuser
       )
       @job1 = Debci::Job.create(
         package: package,
         suite: 'testing',
         arch: 'amd64',
         status: 'pass',
-        date: '2019-02-01 11:00'
+        date: '2019-02-01 11:00',
+        requestor: theuser
       )
       # pending/unfinished job
       @job3 = Debci::Job.create(
         package: package,
         suite: 'testing',
         arch: 'amd64',
+        requestor: theuser
       )
       # migration test
       @job4 = Debci::Job.create(
@@ -154,7 +176,18 @@ describe Debci::Job do
         status: 'fail',
         date: '2019-02-03 11:00',
         trigger: 'bar/1.1-1',
-        pin_packages: [['src:bar', 'unstable']]
+        pin_packages: [['src:bar', 'unstable']],
+        requestor: theuser
+      )
+      # private jobs test
+      @job5 = Debci::Job.create(
+        package: package,
+        suite: 'testing',
+        arch: 'amd64',
+        status: 'fail',
+        date: '2019-02-03 11:00',
+        pin_packages: [['src:bar', 'unstable']],
+        is_private: true
       )
 
       @history = Debci::Job.history(package, 'testing', 'amd64')
@@ -173,6 +206,10 @@ describe Debci::Job do
     it 'does not include jobs with pinned packages' do
       expect(@history).to_not include(@job3)
     end
+
+    it 'does not include private jobs' do
+      expect(@history).to_not include(@job5)
+    end
   end
 
   context 'generating JSON' do
@@ -211,7 +248,7 @@ describe Debci::Job do
         package: package,
         suite: 'unstable',
         arch: 'amd64',
-        requestor: 'user'
+        requestor: theuser
       )
     end
 
@@ -232,7 +269,13 @@ describe Debci::Job do
 
     it('returns job instance') { expect(job.id).to eq(original_job.id) }
     it('gets status') { expect(job.status).to eq('pass') }
-    it('gets worker') { expect(job.worker).to eq('ci-worker-1') }
+
+    it('gets worker and creates new worker entry if does not exist') do
+      expect(Debci::Worker.where(name: 'ci-worker-1')).to_not be_present
+      expect(job.worker).to be_a Debci::Worker
+      expect(Debci::Worker.where(name: 'ci-worker-1')).to be_present
+    end
+
     it('gets message') { expect(job.message).to eq('All tests passed') }
     it('gets duration') { expect(job.duration_seconds).to eq(9) }
     it('gets date') { expect(job.date).to eq(past) }
@@ -265,7 +308,7 @@ describe Debci::Job do
         package: package,
         suite: 'unstable',
         arch: 'amd64',
-        requestor: 'user'
+        requestor: theuser
       )
     end
 
@@ -294,6 +337,7 @@ describe Debci::Job do
         status: 'neutral',
         date: past + 1.day,
         pin_packages: [["src:bla", "unstable"]],
+        requestor: theuser
       )
       expect(second_job.status).to eq('fail')
       expect(second_job.previous_status).to eq(first_job.status)
@@ -327,6 +371,7 @@ describe Debci::Job do
         arch: 'amd64',
         status: 'pass',
         date: Time.now - 1.day,
+        requestor: theuser
       }
     end
 
@@ -366,13 +411,19 @@ describe Debci::Job do
       Debci::Job.create!(data.merge(date: Time.now, pin_packages: ['experimental', 'src:foobar']))
       expect(package_status.job).to eq(job)
     end
+
+    it 'ignores private tests' do
+      job = first_job
+      Debci::Job.create!(data.merge(is_private: true))
+      expect(package_status.job).to eq(job)
+    end
   end
 
   context 'getting status' do
     it 'picks finished jobs for status' do
-      j1 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now - 1.day)
-      j2 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'i386', status: 'fail', date: Time.now - 1.day)
-      j3 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64')
+      j1 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now - 1.day, requestor: theuser)
+      j2 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'i386', status: 'fail', date: Time.now - 1.day, requestor: theuser)
+      j3 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', requestor: theuser)
 
       s = Debci::Job.status_on('unstable', 'amd64')
       expect(s).to include(j1)
@@ -384,8 +435,8 @@ describe Debci::Job do
   context 'getting platform specific issues' do
     before(:each) do
       allow(Debci.config).to receive(:arch_list).and_return(['amd64', 'arm64'])
-      @pass = package.jobs.create!(date: Time.now, status: 'pass', suite: 'unstable', arch: 'amd64')
-      @fail = package.jobs.create!(date: Time.now, status: 'fail', suite: 'unstable', arch: 'arm64')
+      @pass = package.jobs.create!(date: Time.now, status: 'pass', suite: 'unstable', arch: 'amd64', requestor: theuser)
+      @fail = package.jobs.create!(date: Time.now, status: 'fail', suite: 'unstable', arch: 'arm64', requestor: theuser)
     end
     it 'lists job that have different results on different architectures' do
       issues = Debci::Job.platform_specific_issues
@@ -396,8 +447,8 @@ describe Debci::Job do
 
     it 'ignores packages without different results' do
       other_package = Debci::Package.create!(name: 'otherpackage')
-      other_package.jobs.create!(date: Time.now, status: 'pass', suite: 'unstable', arch: 'amd64')
-      other_package.jobs.create!(date: Time.now, status: 'pass', suite: 'unstable', arch: 'arm64')
+      other_package.jobs.create!(date: Time.now, status: 'pass', suite: 'unstable', arch: 'amd64', requestor: theuser)
+      other_package.jobs.create!(date: Time.now, status: 'pass', suite: 'unstable', arch: 'arm64', requestor: theuser)
 
       issues = Debci::Job.platform_specific_issues
       expect(issues).to_not include(other_package)
@@ -420,16 +471,48 @@ describe Debci::Job do
 
   context 'testing for newsworthiness' do
     it 'is newsworthy on status transitions' do
-      job1 = package.jobs.create!(date: Time.now - 1.day, status: 'fail', previous_status: 'pass', suite: 'unstable', arch: 'amd64')
-      job2 = package.jobs.create!(date: Time.now, status: 'fail', previous_status: 'fail', suite: 'unstable', arch: 'amd64')
+      job1 = package.jobs.create!(date: Time.now - 1.day, status: 'fail', previous_status: 'pass', suite: 'unstable', arch: 'amd64', requestor: theuser)
+      job2 = package.jobs.create!(date: Time.now, status: 'fail', previous_status: 'fail', suite: 'unstable', arch: 'amd64', requestor: theuser)
       news = Debci::Job.newsworthy
       expect(news).to include(job1)
       expect(news).to_not include(job2)
     end
 
     it 'is not newsworthy with pinned packages' do
-      job = package.jobs.create!(date: Time.now - 1.day, status: 'fail', previous_status: 'pass', suite: 'unstable', arch: 'amd64', pin_packages: [["src:foo", "src:bar", "unstable"]])
+      job = package.jobs.create!(date: Time.now - 1.day, status: 'fail', previous_status: 'pass', suite: 'unstable', arch: 'amd64', pin_packages: [["src:foo", "src:bar", "unstable"]], requestor: theuser)
       expect(Debci::Job.newsworthy).to_not include(job)
     end
   end
+
+  context 'status_on' do
+    it 'does not include jobs of removed packages' do
+      job1 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor: theuser)
+      other_package = Debci::Package.create!(name: 'otherpackage', removed: true)
+      job2 = Debci::Job.create!(package: other_package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor: theuser)
+      s = Debci::Job.status_on("unstable", "amd64")
+      expect(s).to include(job1)
+      expect(s).to_not include(job2)
+    end
+
+    it 'does not include private jobs' do
+      job1 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor: theuser, is_private: true)
+      job2 = Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor: theuser)
+      s = Debci::Job.status_on("unstable", "amd64")
+      expect(s).to_not include(job1)
+      expect(s).to include(job2)
+    end
+  end
+
+  context 'creating jobs' do
+    it 'does not create jobs with requestor missing' do
+      expect { Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now) }.to raise_error(ActiveRecord::RecordInvalid)
+      expect { Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor: theuser) }.to_not raise_error
+    end
+
+    it 'creates jobs with only valid requestor_id present in users' do
+      expect(Debci::User.where(id: 12345)).to be_empty
+      expect { Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor_id: 12345) }.to raise_error(ActiveRecord::RecordInvalid)
+      expect { Debci::Job.create!(package: package, suite: 'unstable', arch: 'amd64', status: 'pass', date: Time.now, requestor: theuser) }.to_not raise_error
+    end
+  end
 end
