@@ -29,7 +29,7 @@ setUp() {
   mkdir -p $__tmpdir/data
   mkdir -p $__tmpdir/config
   mkdir -p $__tmpdir/lock
-  cat > "$__tmpdir/config/whitelist" <<EOF
+  cat > "$__tmpdir/config/seed_list" <<EOF
 ruby
 ruby-ffi
 rubygems-integration
@@ -43,6 +43,10 @@ EOF
   debci migrate --quiet
 }
 
+submit_tests() {
+  debci-enqueue $(cat ${debci_config_dir}/seed_list)
+}
+
 status_dir_for_package() {
   local pkg="$1"
   pkg_dir=$(echo "$pkg" | sed -e 's/\(\(lib\)\?.\).*/\1\/&/')
@@ -146,7 +150,7 @@ start_worker() {
   start_rabbitmq_server
   stop_worker  # in case a test does multiple runs under different modes
   start_collector
-  export debci_batch_poll_interval="0.1"
+  export debci_poll_interval="0.1"
   PATH="$testbin:$PATH" debci worker &
   TEST_WORKER_PID=$!
   sleep 0.1
